@@ -530,18 +530,21 @@ from django.utils.safestring import mark_safe
 class DataTransform(forms.ModelForm):
     id = forms.CharField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    accessory = forms.CharField(required=False,
+    accessory = forms.ModelChoiceField(required=True,queryset=Accessory.objects.all(),
                                 widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
-    parent = forms.CharField(required=False,
+    parent = forms.ModelChoiceField(required=True,queryset=DataTransformer.objects.all(),
                              widget=forms.HiddenInput(attrs={'class': 'form-control'}))
 
+    type = forms.ModelChoiceField(required=True, queryset=DataTransformerTypes.objects.all())
+
+
     def __init__(self, *args, **kwargs):
         print('Init Data Transform')
         super(DataTransform, self).__init__(*args, **kwargs)
-        types = list(
-            DataTransformerTypes.objects.all().values_list('type', 'type'))
-        self.fields['type'] = ChoiceField(choices=tuple(types))
+        # types = list(
+        #     DataTransformerTypes.objects.all().values_list('type', 'type'))
+        # self.fields['type'] = ChoiceField(choices=tuple(types))
         try:
             if hasattr(self.instance, 'get_children') and self.instance.get_children().count() > 0:
                 print('Adding to child form node: ' + str(self.instance.get_children().count() + 1))
@@ -612,13 +615,13 @@ class DataTransform(forms.ModelForm):
         print('save: ' + str(self.instance.id))
         super(DataTransform, self).save(commit)
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.save()
+            self.nested_constants_form.save(commit)
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            self.nested_hardware_outputs_form.save()
+            self.nested_hardware_outputs_form.save(commit)
         if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            self.nested_hardware_stats_form.save()
+            self.nested_hardware_stats_form.save(commit)
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            self.nested_data_transformer_form.save()
+            self.nested_data_transformer_form.save(commit)
 
     class Meta:
         model = DataTransformer
@@ -631,16 +634,17 @@ class DataTransform(forms.ModelForm):
 class DataTransformRoot(forms.ModelForm):
     id = forms.CharField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    accessory = forms.CharField(required=False,
-                                widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    accessory = forms.ModelChoiceField(required=True, queryset=Accessory.objects.all(),
+                                       widget=forms.HiddenInput(attrs={'class': 'form-control'}))
+    type = forms.ModelChoiceField(required=True, queryset=DataTransformerTypes.objects.all())
 
     # def __init__(self, *args, **kwargs):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
-        types = list(
-            DataTransformerTypes.objects.all().values_list('type', 'type'))
-        self.fields['type'] = ChoiceField(choices=tuple(types))
+        # types = list(
+        #     DataTransformerTypes.objects.all().values_list('type', 'type'))
+        # self.fields['type'] = ChoiceField(choices=tuple(types))
         try:
             if hasattr(self.instance, 'get_children'):
                 print('Adding to root form node: ' + str(self.instance.get_children().count() + 1))
@@ -712,13 +716,13 @@ class DataTransformRoot(forms.ModelForm):
         print('save: ' + str(self.instance.id))
         super(DataTransformRoot, self).save(commit)
         if hasattr(self, 'nested_constants_form') and self.nested_constants_form is not None:
-            self.nested_constants_form.save()
+            self.nested_constants_form.save(commit)
         if hasattr(self, 'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            self.nested_hardware_outputs_form.save()
+            self.nested_hardware_outputs_form.save(commit)
         if hasattr(self, 'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
-            self.nested_hardware_stats_form.save()
+            self.nested_hardware_stats_form.save(commit)
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
-            self.nested_data_transformer_form.save()
+            self.nested_data_transformer_form.save(commit)
 
     class Meta:
         model = DataTransformer
